@@ -18,8 +18,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Date.py 5875 2006-02-03 22:03:53Z rshura $
+# $Id$
 
+"""
 
-# FIXME: this module is only needed to to enable db upgrade
-from RelLib import Date
+this module is only needed to to enable db upgrade
+
+"""
+
+from gen.lib import Date
