@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_ru.py 22670 2013-07-13 18:00:11Z paul-franklin $
+# $Id$
 
 """
 Russian-specific classes for parsing and displaying dates.
@@ -51,6 +51,7 @@ class DateParserRU(DateParser):
 
     modifier_to_int = {
         u'перед'    : Date.MOD_BEFORE, 
+        u'до'    : Date.MOD_BEFORE, 
         u'по'    : Date.MOD_BEFORE, 
         u'после' : Date.MOD_AFTER, 
         u'п.'    : Date.MOD_AFTER, 
@@ -257,7 +258,7 @@ class DateDisplayRU(DateDisplay):
 
     _mod_str = (
         u"", 
-        u"перед ", 
+        u"до ", 
         u"после ", 
         u"около ", 
         u"", u"", u"")
