@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasEventBase.py 21933 2013-04-09 13:51:07Z nick-h $
+# $Id$
 
 #-------------------------------------------------------------------------
 #
@@ -50,7 +50,8 @@ class HasEventBase(Rule):
                     _('Date:'), 
                     _('Place:'), 
                     _('Description:'),
-                    _('Main Participants') ]
+                    _('Main Participants:'),
+                    _('Primary Role:') ]
     name        =  _('Events matching parameters')
     description =  _("Matches events with particular parameters")
     category    = _('Event filters')
