@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: mergeperson.py 18669 2011-12-31 18:47:05Z m_d_n $
+# $Id$
 
 """
 Provide merge capabilities for persons.
@@ -72,7 +72,7 @@ class MergePeople(ManagedWindow.ManagedWindow):
     Displays a dialog box that allows the persons to be combined into one.
     """
     def __init__(self, dbstate, uistate, handle1, handle2, cb_update=None,
-            expand_context_info=False):
+            expand_context_info=True):
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self.__class__)
         self.database = dbstate.db
         self.pr1 = self.database.get_person_from_handle(handle1)
