@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: selectnote.py 16027 2010-10-23 13:11:35Z nick-h $
+# $Id$
 
 """Handling of selection dialog for selecting notes
 """
@@ -66,7 +66,8 @@ class SelectNote(BaseSelector):
             (_('Preview'), 350, BaseSelector.TEXT, 0),
             (_('ID'),      75,  BaseSelector.TEXT, 1),
             (_('Type'),    100, BaseSelector.TEXT, 2),
-            (_('Tags'),    100, BaseSelector.TEXT, 3)
+            (_('Tags'),    100, BaseSelector.TEXT, 3),
+            (_('Last Change'), 150, BaseSelector.TEXT, 4),
             ]
             
     def get_from_handle_func(self):
