@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: navigationview.py 19999 2012-07-14 14:05:00Z paul-franklin $
+# $Id$
 
 """
 Provide the base classes for GRAMPS' DataView classes
@@ -82,7 +82,7 @@ class NavigationView(PageView):
     def __init__(self, title, pdata, state, uistate, bookmarks, bm_type, nav_group):
         PageView.__init__(self, title, pdata, state, uistate)
         self.bookmarks = bm_type(self.dbstate, self.uistate, bookmarks,
-                                 self.goto_handle)
+                                 self.change_active)
 
         self.fwd_action = None
         self.back_action = None
@@ -364,7 +364,6 @@ class NavigationView(PageView):
             handle = self.get_handle_from_gramps_id(gid)
             if handle is not None:
                 self.change_active(handle)
-                self.goto_handle(handle)
             else:
                 self.uistate.push_message(
                     self.dbstate, 
