@@ -23,7 +23,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportGedcom.py 21608 2013-03-11 18:44:01Z kulath $
+# $Id$
 
 "Export to GEDCOM"
 
@@ -634,7 +634,7 @@ class GedcomWriter(UpdateCallback):
             key = str(attr.get_type())
             value = attr.get_value().strip().replace('\r', ' ')
             
-            if key in ("AFN", "RFN", "REFN", "_UID"):
+            if key in ("AFN", "RFN", "REFN", "_UID", "_FSFTID"):
                 self.__writeln(1, key, value)
                 continue
 
@@ -876,10 +876,11 @@ class GedcomWriter(UpdateCallback):
             
             attr_type = int(attr.get_type())
             name = libgedcom.FAMILYCONSTANTATTRIBUTES.get(attr_type)
+            key = str(attr.get_type())
             value = attr.get_value().replace('\r', ' ')
 
-            if attr_type in ("AFN", "RFN", "REFN", "_UID"):
-                self.__writeln(1, attr_type, value)
+            if key in ("AFN", "RFN", "REFN", "_UID"):
+                self.__writeln(1, key, value)
                 continue
             
             if name and name.strip():
@@ -887,7 +888,7 @@ class GedcomWriter(UpdateCallback):
                 continue
             else:
                 self.__writeln(1, 'FACT', value)
-                self.__writeln(2, 'TYPE', str(attr.get_type()))
+                self.__writeln(2, 'TYPE', key)
 
             self.__note_references(attr.get_note_list(), level+1)
             self.__source_references(attr.get_citation_list(), 
