@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: geoevents.py 19847 2012-06-16 09:16:55Z noirauds $
+# $Id$
 
 """
 Geography for events
@@ -171,6 +171,17 @@ class GeoEvents(GeoGraphyView):
         """
         return self.dbstate.db.get_event_bookmarks()
 
+    def add_bookmark(self, obj):
+        mlist = self.selected_handles()
+        if mlist:
+            self.bookmarks.add(mlist[0])
+        else:
+            from QuestionDialog import WarningDialog
+            WarningDialog(
+                _("Could Not Set a Bookmark"), 
+                _("A bookmark could not be set because "
+                  "no one was selected."))
+
     def goto_handle(self, handle=None):
         """
         Rebuild the tree with the given events handle as the root.
@@ -205,8 +216,11 @@ class GeoEvents(GeoGraphyView):
         """
         dbstate = self.dbstate
         descr = descr2 = ""
-        place_handle = event.get_place_handle()
-        eventyear = event.get_date_object().to_calendar(self.cal).get_year()
+        if event:
+            place_handle = event.get_place_handle()
+            eventyear = event.get_date_object().to_calendar(self.cal).get_year()
+        else:
+            place_handle = None
         if place_handle:
             place = dbstate.db.get_place_from_handle(place_handle)
             if place:
