@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: geofamily.py 19847 2012-06-16 09:16:55Z noirauds $
+# $Id$
 
 """
 Geography for one family
@@ -170,6 +170,18 @@ class GeoFamily(GeoGraphyView):
         """
         return self.dbstate.db.get_family_bookmarks()
 
+    def add_bookmark(self, obj):
+        mlist = self.selected_handles()
+        print mlist
+        if mlist:
+            self.bookmarks.add(mlist[0])
+        else:
+            from QuestionDialog import WarningDialog
+            WarningDialog(
+                _("Could Not Set a Bookmark"), 
+                _("A bookmark could not be set because "
+                  "no one was selected."))
+
     def goto_handle(self, handle=None):
         """
         Rebuild the tree with the given person handle as the root.
